@@ -1,5 +1,5 @@
 "envfit" <-
-function (X, P, permutations = 0, strata) 
+    function (X, P, permutations = 0, strata, choices=c(1,2)) 
 {
     vectors <- NULL
     factors <- NULL
@@ -7,23 +7,23 @@ function (X, P, permutations = 0, strata)
     if (is.data.frame(P)) {
         facts <- unlist(lapply(P, is.factor))
         if (sum(facts)) {
-            Pfac <- P[, facts]
-            P <- P[, !facts]
+            Pfac <- P[, facts, drop=FALSE]
+            P <- P[, !facts, drop=FALSE]
             if (length(P)) {
                 if (permutations) {
-                  runif(1)
-                  seed <- .Random.seed
+                    runif(1)
+                    seed <- .Random.seed
                 }
-                vectors <- vectorfit(X, P, permutations, strata)
+                vectors <- vectorfit(X, P, permutations, strata, choices)
             }
             if (!is.null(seed)) 
                 .Random.seed <- seed
-            factors <- factorfit(X, Pfac, permutations, strata)
+            factors <- factorfit(X, Pfac, permutations, strata, choices)
             sol <- list(vector = vectors, factors = factors)
         }
-        else vectors <- vectorfit(X, P, permutations, strata)
+        else vectors <- vectorfit(X, P, permutations, strata, choices)
     }
-    else vectors <- vectorfit(X, P, permutations, strata)
+    else vectors <- vectorfit(X, P, permutations, strata, choices)
     sol <- list(vectors = vectors, factors = factors)
     class(sol) <- "envfit"
     sol
