@@ -3,7 +3,7 @@ function (object, scaling = 2, axes = 6, digits = max(3, getOption("digits") -
     3), ...) 
 {
     axes <- min(axes, sum(object$CCA$rank, object$CA$rank))
-    summ <- object[c("Call", "tot.chi")]
+    summ <- object[c("call", "tot.chi")]
     summ$partial.chi <- object$pCCA$tot.chi
     summ$constr.chi <- object$CCA$tot.chi
     summ$unconst.chi <- object$CA$tot.chi
@@ -24,11 +24,16 @@ function (object, scaling = 2, axes = 6, digits = max(3, getOption("digits") -
     species <- object$CCA$v[, 1:cc.dim, drop = FALSE]
     sites <- object$CCA$wa.eig[, 1:cc.dim, drop = FALSE]
     site.constr <- object$CCA$u[, 1:cc.dim, drop = FALSE]
+    centroids <- NA
+    if (!is.null(object$CCA$centroids) && !is.na(object$CCA$centroids)[1]) 
+        centroids <- object$CCA$centroids[, 1:cc.dim, drop = FALSE]
     evscale <- sqrt(summ$ev.con[1:cc.dim])
     if (scaling == 2) {
         if (cc.dim) {
             species <- sweep(species, 2, evscale, "*")
             sites <- sweep(sites, 2, evscale, "/")
+            if (!is.na(centroids)[1]) 
+                centroids <- sweep(centroids, 2, evscale, "/")
         }
         if (add.dim) {
             evscale0 <- sqrt(summ$ev.uncon[1:add.dim])
@@ -39,7 +44,7 @@ function (object, scaling = 2, axes = 6, digits = max(3, getOption("digits") -
         }
     }
     if (scaling == 1) {
-        if (cc.dim)
+        if (cc.dim) 
             site.constr <- sweep(site.constr, 2, evscale, "*")
         if (add.dim) {
             evscale0 <- sqrt(summ$ev.uncon[1:add.dim])
@@ -54,7 +59,11 @@ function (object, scaling = 2, axes = 6, digits = max(3, getOption("digits") -
         if (cc.dim) {
             species <- sweep(species, 2, sqrt(evscale), "*")
             sites <- sweep(sites, 2, sqrt(evscale), "/")
-            site.constr <- sweep(site.constr, 2, sqrt(evscale), "*")
+            if (!is.na(centroids)[1]) 
+                centroids <- sweep(centroids, 2, sqrt(evscale), 
+                  "/")
+            site.constr <- sweep(site.constr, 2, sqrt(evscale), 
+                "*")
         }
         if (add.dim) {
             evscale0 <- sqrt(sqrt(summ$ev.uncon[1:add.dim]))
@@ -70,6 +79,7 @@ function (object, scaling = 2, axes = 6, digits = max(3, getOption("digits") -
     summ$sites <- sites
     summ$constraints <- site.constr
     summ$biplot <- biplot
+    summ$centroids <- centroids
     summ$digits <- digits
     class(summ) <- "summary.cca"
     summ
